@@ -2,29 +2,17 @@
 import factory
 
 from django_libs.tests.factories import UserFactory
-from django_libs.tests.factories import SimpleTranslationMixin
+from django_libs.tests.factories import HvadFactoryMixin
 
 from .. import models
 
 
-class BookingStatusFactory(SimpleTranslationMixin, factory.Factory):
+class BookingStatusFactory(HvadFactoryMixin, factory.DjangoModelFactory):
     """Factory for the ``BookingStatus`` model."""
     FACTORY_FOR = models.BookingStatus
 
     slug = factory.Sequence(lambda x: 'status-{}'.format(x))
-
-    @staticmethod
-    def _get_translation_factory_and_field():
-        return (BookingStatusTranslationFactory, 'status')
-
-
-class BookingStatusTranslationFactory(factory.Factory):
-    """Factory for ``BookingStatusTranslation`` objects."""
-    FACTORY_FOR = models.BookingStatusTranslation
-
-    name = factory.Sequence(lambda x: 'Status {}'.format(x))
-    status = factory.SubFactory(BookingStatusFactory)
-    language = 'en'
+    name = factory.Sequence(lambda n: 'Status {0}'.format(n))
 
 
 class BookingFactory(factory.DjangoModelFactory):
@@ -44,6 +32,13 @@ class BookingItemFactory(factory.DjangoModelFactory):
     booked_item = factory.SubFactory(UserFactory)
 
 
+class BookingErrorFactory(factory.DjangoModelFactory):
+    """Factory for the ``BookingError`` model."""
+    FACTORY_FOR = models.BookingError
+
+    booking = factory.SubFactory(BookingFactory)
+
+
 class ExtraPersonInfoFactory(factory.DjangoModelFactory):
     """Factory for the ``ExtraPersonInfo`` model."""
     FACTORY_FOR = models.ExtraPersonInfo
